@@ -11,6 +11,7 @@ KNOWN_PKG_TYPES = [
     "npm",
     "nuget",
     "pypi",
+    "gem",
     "rubygems",
     "golang",
     "crates",
@@ -21,8 +22,9 @@ PKG_TYPES_MAP = {
     "composer": ["php", "laravel", "wordpress", "joomla"],
     "maven": ["jenkins", "java", "kotlin", "groovy"],
     "npm": ["javascript", "node.js", "nodejs"],
-    "nuget": [".net_framework", "csharp", ".net_core"],
+    "nuget": [".net_framework", "csharp", ".net_core", "asp.net"],
     "pypi": ["python"],
+    "gem": ["ruby"],
     "rubygems": ["ruby", "gem"],
     "golang": ["go"],
     "crates": ["rust", "crates.io", "cargo"],
